================
Jexia Python SDK
================

.. image:: https://circleci.com/gh/jexia/jexia-sdk-python/tree/master.svg?style=svg
    :target: https://circleci.com/gh/jexia/jexia-sdk-python/tree/master
    :alt: Build status
.. image:: https://coveralls.io/repos/jexia/jexia-sdk-python/badge.svg?branch=master
    :target: https://coveralls.io/r/jexia/jexia-sdk-python?branch=master
    :alt: Code coverage
.. image:: https://readthedocs.org/projects/jexia-sdk/badge/?version=latest
    :target: https://jexia-sdk.readthedocs.io/en/latest/
    :alt: Documentation status
.. image:: https://img.shields.io/pypi/l/jexia-sdk.svg
    :target: https://pypi.org/project/jexia-sdk
    :alt: License
.. image:: https://img.shields.io/pypi/pyversions/jexia-sdk.svg
    :target: https://pypi.org/project/jexia-sdk
    :alt: Supported Python versions

This is the official Python SDK for interacting with Jexia projects.


Compatibility
=============

Jexia-SDK requires Python 2.7.15+.


Installation
============

You can install jexia-sdk with pip:

.. code-block:: console

    $ pip install jexia-sdk

or with easy_install:

.. code-block:: console

    $ easy_install jexia-sdk


Quick start
===========

TODO


Contributors
============

Jexia-SDK is brought to you by @velp.

Of course, everyone is welcome to contribute and we will be happy to review your
PR's or answer to your issues.


Documentation
=============

The documentation is hosted `on Read the Docs <http://jexia-sdk.readthedocs.io/en/latest/>`__


Contribution
============
Want to contribute! That's awesome! Check out `CONTRIBUTING.rst! <https://github.com/jexia/jexia-sdk/blob/master/CONTRIBUTING.rst>`__
